package smash.appointment.parse;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

public class AppointmentDao {
	Logger												 logger				= Logger.getLogger(AppointmentDao.class);
	private List<AppointmentEntry> appointments	= new ArrayList<>();

	public void addAppointments(List<AppointmentEntry> appointmentsToAdd) {
		for (AppointmentEntry appointmentEntry : appointmentsToAdd) {
			addAppointment(appointmentEntry);
		}
	}

	/**
	 * @return the appointments
	 * @see #appointments
	 */
	public List<AppointmentEntry> getAppointments() {
		return appointments;
	}

	/**
	 * @param appointments
	 *          the appointments to set
	 * @see #appointments
	 */
	public void setAppointments(List<AppointmentEntry> appointments) {
		this.appointments = appointments;
	}

	public List<Visit> getVisits() throws ParseException {
		List<Visit> result = new ArrayList<>();
		Map<Subject, List<AppointmentEntry>> subjectAppointments = new HashMap<>();
		for (AppointmentEntry entry : appointments) {
			if (subjectAppointments.get(entry.getSubject()) == null) {
				subjectAppointments.put(entry.getSubject(), new ArrayList<AppointmentEntry>());
			}
			subjectAppointments.get(entry.getSubject()).add(entry);
		}
		for (Subject subject : subjectAppointments.keySet()) {
			result.addAll(getVisitsForSubject(subject, subjectAppointments.get(subject)));
		}
		return result;
	}

	private List<Visit> getVisitsForSubject(Subject subject, List<AppointmentEntry> list) throws ParseException {
		Comparator<AppointmentEntry> comparator = new Comparator<AppointmentEntry>() {

			@Override
			public int compare(AppointmentEntry o1, AppointmentEntry o2) {
				String date1 = o1.getDay().substring(0, 10);
				String date2 = o2.getDay().substring(0, 10);
				if (date1.compareTo(date2) == 0) {
					if (o1.getTypes().contains(AppointmentType.LEVEL_AQUEST) || o1.getTypes().contains(AppointmentType.LEVEL_A_TQ)) {
						return -1;
					} else if (o2.getTypes().contains(AppointmentType.LEVEL_AQUEST) || o2.getTypes().contains(AppointmentType.LEVEL_A_TQ)) {
						return 1;
					} else {
						return 0;
					}
				} else {
					return date1.compareTo(date2);
				}
			}
		};
		Collections.sort(list, comparator);

		List<Visit> result = new ArrayList<>();
		Visit currentVisit = new Visit(subject);
		for (AppointmentEntry appointmentEntry : list) {
			if (appointmentEntry.getTypes().contains(AppointmentType.LEVEL_AQUEST) || appointmentEntry.getTypes().contains(AppointmentType.LEVEL_A_TQ)) {
				if (currentVisit.getAppointments().size() > 0) {
					if (shouldBeFinished(currentVisit.getEndDate())) {
						currentVisit.setFinished(true);
					}
					result.add(currentVisit);
				}

				currentVisit = new Visit(subject);
				currentVisit.addAppointment(appointmentEntry);
			} else {
				String date = currentVisit.getLastAppointmentDate();
				if (date.equals(appointmentEntry.getDay().substring(0, 10))) {
					currentVisit.getLastAppointment().addTypes(appointmentEntry.getTypes());
					String source = appointmentEntry.getSource() + "\n" + currentVisit.getLastAppointment().getSource();
					currentVisit.getLastAppointment().setSource(source);
				} else {
					currentVisit.addAppointment(appointmentEntry);
				}
			}
		}
		if (currentVisit.getAppointments().size() > 0) {
			result.add(currentVisit);
		}
		if (shouldBeFinished(currentVisit.getEndDate())) {
			currentVisit.setFinished(true);
			if (!subject.isDead() && !subject.isResigned()) {
				result.add(createNextVisit(currentVisit));
			}
		}
		return result;
	}

	protected Visit createNextVisit(Visit currentVisit) throws ParseException {
		Visit visit = new Visit(currentVisit.getSubject());
		Calendar date = Calendar.getInstance();
		String dateStr = currentVisit.getStartDate();
		date.setTime(DATE_FORMATTER.parse(dateStr));
		if (currentVisit.getSubject().getType().equals(SubjectType.CONTROL)) {
			date.add(Calendar.YEAR, 4);
		} else {
			date.add(Calendar.YEAR, 1);
		}
		visit.setStartDate(DATE_FORMATTER.format(date.getTime()));
		return visit;
	}

	private static final SimpleDateFormat DATE_FORMATTER = new SimpleDateFormat("yyyy-MM-dd");

	protected boolean shouldBeFinished(String endDate) {
		Calendar today_minus_two_months = Calendar.getInstance();
		today_minus_two_months.add(Calendar.MONTH, -2);
		return DATE_FORMATTER.format(today_minus_two_months.getTime()).compareTo(endDate) > 0;
	}

	public void addAppointment(AppointmentEntry appointment) {
		appointments.add(appointment);

	}

}
