package smash.appointment.parse;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.text.ParseException;

import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.Test;

public class AppointmentDaoTest {
	Logger logger = Logger.getLogger(AppointmentDaoTest.class);

	@AfterClass
	public static void tearDownAfterClass() throws Exception {
	}

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void getVisits() throws ParseException {
		Subject subject1 = new Subject("a", "b", "c", "d");
		AppointmentEntry appointment = new AppointmentEntry();
		appointment.setSubject(subject1);
		appointment.setDay("2026-02-02");
		appointment.addType(AppointmentType.LEVEL_AQUEST);

		AppointmentEntry appointment2 = new AppointmentEntry();
		appointment2.setSubject(subject1);
		appointment2.setDay("2026-02-02");
		appointment2.addType(AppointmentType.LEVEL_B);

		AppointmentEntry appointment3 = new AppointmentEntry();
		appointment3.setSubject(subject1);
		appointment3.setDay("2021-02-02");
		appointment3.addType(AppointmentType.LEVEL_AQUEST);

		AppointmentDao appointmentDao = new AppointmentDao();
		appointmentDao.addAppointment(appointment);
		appointmentDao.addAppointment(appointment2);
		appointmentDao.addAppointment(appointment3);
		assertEquals(2, appointmentDao.getVisits().size());
	}

	@Test
	public void getVisits2() throws ParseException {
		Subject subject1 = new Subject("a", "b", "c", "d");
		Subject subject2 = new Subject("a1", "b1", "c1", "d1");
		AppointmentEntry appointment = new AppointmentEntry();
		appointment.setSubject(subject1);
		appointment.setDay("2026-02-02");
		appointment.addType(AppointmentType.LEVEL_AQUEST);

		AppointmentEntry appointment3 = new AppointmentEntry();
		appointment3.setSubject(subject2);
		appointment3.setDay("2026-02-02");
		appointment3.addType(AppointmentType.LEVEL_B);

		AppointmentDao appointmentDao = new AppointmentDao();
		appointmentDao.addAppointment(appointment);
		appointmentDao.addAppointment(appointment3);
		assertEquals(2, appointmentDao.getVisits().size());
	}

	@Test
	public void getShouldBeFinished() {
		AppointmentDao appointmentDao = new AppointmentDao();
		assertTrue(appointmentDao.shouldBeFinished("2014-01-01"));
		assertTrue(appointmentDao.shouldBeFinished("2017-01-01"));
		assertFalse(appointmentDao.shouldBeFinished("2018-01-01"));
	}

	@Test
	public void createNextVisitForControl() throws ParseException {
		Subject subject = new Subject("a", "b", "c", "d");
		subject.setType(SubjectType.CONTROL);
		AppointmentEntry appointment3 = new AppointmentEntry();
		appointment3.setSubject(subject);
		appointment3.setDay("2016-02-02");
		appointment3.addType(AppointmentType.LEVEL_B);

		Visit visit = new Visit(subject);
		visit.addAppointment(appointment3);

		AppointmentDao appointmentDao = new AppointmentDao();
		Visit nextVisit = appointmentDao.createNextVisit(visit);
		assertNotNull(nextVisit);
		assertTrue(nextVisit.getStartDate().startsWith("2020"));
	}

	@Test
	public void createNextVisitForPatient() throws ParseException {
		Subject subject = new Subject("a", "b", "c", "d");
		subject.setType(SubjectType.PATIENT);
		AppointmentEntry appointment3 = new AppointmentEntry();
		appointment3.setSubject(subject);
		appointment3.setDay("2016-02-02");
		appointment3.addType(AppointmentType.LEVEL_B);

		Visit visit = new Visit(subject);
		visit.addAppointment(appointment3);

		AppointmentDao appointmentDao = new AppointmentDao();
		Visit nextVisit = appointmentDao.createNextVisit(visit);
		assertNotNull(nextVisit);
		assertTrue(nextVisit.getStartDate().startsWith("2017"));
	}

}
