import datetime

from django.http import JsonResponse
from django.utils import timezone

from web.models.constants import GLOBAL_STUDY_ID
from web.api_views.daily_planning import get_workers_for_daily_planning, get_availabilities
from ..models import Worker


def specializations(request):
    workers = Worker.objects.filter(specialization__isnull=False).values_list('specialization').distinct()
    return JsonResponse({
        "specializations": [x[0] for x in workers]
    })


def units(request):
    workers = Worker.objects.filter(unit__isnull=False).values_list('unit').distinct()
    return JsonResponse({
        "units": [x[0] for x in workers]
    })


def workers_for_daily_planning(request):
    workers = get_workers_for_daily_planning(request)
    workers_list_for_json = []
    for worker in workers:
        role = unicode(worker.roles.filter(study_id=GLOBAL_STUDY_ID)[0].role)
        worker_dict_for_json = {
            'id': worker.id,
            'title': u"{} ({})".format(unicode(worker), role[:1].upper()),
            'role': role
        }
        workers_list_for_json.append(worker_dict_for_json)
    return JsonResponse(workers_list_for_json, safe=False)


def availabilities(request):
    result = []
    min_date = request.GET.get("start_date")
    max_date = request.GET.get("end_date")

    workers = get_workers_for_daily_planning(request)

    min_date = datetime.datetime.strptime(min_date, "%Y-%m-%d").replace(tzinfo=timezone.now().tzinfo)
    max_date = datetime.datetime.strptime(max_date, "%Y-%m-%d").replace(tzinfo=timezone.now().tzinfo)

    while min_date <= max_date:
        str_date = min_date.strftime('%Y-%m-%d')
        date_result = {"date": str_date, "workers": []}
        for worker in workers:
            if len(get_availabilities(worker, str_date)) > 0:
                date_result["workers"].append({
                    "worker_id": worker.id,
                    "initials": worker.initials(),
                })
        result.append(date_result)
        min_date += datetime.timedelta(days=1)

    return JsonResponse({
        "availabilities": result,
    })


def get_workers(request, worker_role):
    all_workers = Worker.get_workers_by_worker_type(worker_role).distinct()
    count = all_workers.count()

    data = []
    for voucher_type in all_workers:
        data.append(serialize_worker(voucher_type))

    return JsonResponse({
        "recordsTotal": count,
        "recordsFiltered": count,
        "data": data,
    })


def serialize_worker(worker):
    result = {
        "first_name": worker.first_name,
        "last_name": worker.last_name,
        "id": worker.id,
    }
    return result
