# coding=utf-8
from django.contrib import messages
from django.urls import reverse_lazy
from django.views.generic import CreateView
from django.views.generic import DeleteView
from django.views.generic import ListView
from django.views.generic import UpdateView

from . import WrappedView
from ..models import Language


class LanguageListView(ListView, WrappedView):
    model = Language
    context_object_name = "languages"
    template_name = 'languages/list.html'


class LanguageCreateView(CreateView, WrappedView):
    model = Language
    template_name = "languages/add.html"
    fields = '__all__'
    success_url = reverse_lazy('web.views.languages')
    success_message = "Language created"


class LanguageDeleteView(DeleteView, WrappedView):
    model = Language
    success_url = reverse_lazy('web.views.languages')
    template_name = 'languages/confirm_delete.html'

    def delete(self, request, *args, **kwargs):
        messages.success(request, "Language deleted")
        return super(LanguageDeleteView, self).delete(request, *args, **kwargs)


class LanguageEditView(UpdateView, WrappedView):
    model = Language
    success_url = reverse_lazy('web.views.languages')
    fields = '__all__'
    success_message = "Language edited"
    template_name = "languages/edit.html"
    context_object_name = "language"
