# coding=utf-8
import logging

from django.contrib import messages
from django.shortcuts import redirect, get_object_or_404

from web.forms import StudyColumnsEditForm, StudyEditForm, StudyNotificationParametersEditForm
from web.models import Study
from web.views import wrap_response

logger = logging.getLogger(__name__)


def study_edit(request, study_id):
    study = get_object_or_404(Study, id=study_id)
    if request.method == 'POST':
        study_form = StudyEditForm(request.POST, request.FILES, instance=study, prefix="study")
        notifications_form = StudyNotificationParametersEditForm(request.POST, request.FILES,
                                                                 instance=study.notification_parameters,
                                                                 prefix="notifications")
        study_columns_form = StudyColumnsEditForm(request.POST, request.FILES, instance=study.columns,
                                                  prefix="columns")
        if study_form.is_valid() and notifications_form.is_valid() and study_columns_form.is_valid():
            study_form.save()
            notifications_form.save()
            study_columns_form.save()
            messages.success(request, "Modifications saved")
            if '_continue' in request.POST:
                return redirect('web.views.edit_study', study_id=study.id)
            return redirect('web.views.appointments')
        else:
            messages.add_message(request, messages.ERROR, 'Invalid data. Please fix data and try again.')
    else:
        study_form = StudyEditForm(instance=study, prefix="study")
        notifications_form = StudyNotificationParametersEditForm(instance=study.notification_parameters,
                                                                 prefix="notifications")
        study_columns_form = StudyColumnsEditForm(instance=study.columns,
                                                  prefix="columns")

    return wrap_response(request, 'study/edit.html', {
        'study_form': study_form,
        'notifications_form': notifications_form,
        'study_columns_form': study_columns_form,
    })
